<?php

if ( ! function_exists( 'pics_root_path' ) ) {
	function pics_root_path( string $rel_path = '' ): string {
		$path = WP_PLUGIN_DIR . '/pics.io';

		if ( ! empty( $rel_path ) ) {
			$path .= $rel_path;
		}

		return $path;
	}
}

/**
 * Get all possible image mime types
 * 
 * @return array
 */
if ( ! function_exists( 'pics_get_allowed_mime_types' ) ){
    function pics_get_image_mime_types(): array  {
        return [
            'image/gif' => 'gif',
            'image/x-icon' => 'ico',
            'image/jpeg' => 'jpe',
            'image/jpeg' => 'jpeg',
            'image/jpeg' => 'jpg',
            'image/png' => 'png',
            'image/svg-xml' => 'svg',
            'image/tiff' => 'tiff',
            'image/x-samsung-srw' => 'srw',
            'image/avif' => 'avif',
            'image/webp' => 'webp',
            'image/x-sony-srf' => 'srf',
            'image/x-pentax-pef' => 'pef',
            'image/bmp' => 'bmp',
            'image/cgm' => 'cgm',
            'image/g3fax' => '',
            'image/heic' => 'heic',
            'image/ief' => 'ief',
            'image/x-png' => 'png',
            'image/vnd.mozilla.apng' => 'png',
            'image/prs.btif' => 'btif',
            'image/vnd.adobe.photoshop' => 'psd',
            'image/vnd.djvu' => 'djvu',
            'image/vnd.dwg' => 'dwg',
            'image/vnd.dxf' => 'dxf',
            'image/vnd.fastbidsheet' => 'fbs',
            'image/vnd.fpx' => 'fpx',
            'image/vnd.fst' => 'fst',
            'image/vnd.fujixerox.edmics-mmr' => 'mmr',
            'image/vnd.fujixerox.edmics-rlc' => 'rlc',
            'image/vnd.ms-modi' => 'mdi',
            'image/vnd.net-fpx' => 'npx',
            'image/vnd.wap.wbmp' => 'wbmp',
            'image/vnd.xiff' => 'xiff',
            'image/x-adobe-dng' => 'dng',
            'image/x-canon-cr2' => 'cr2',
            'image/x-canon-crw' => 'crw',
            'image/x-cmu-raster' => 'ras',
            'image/x-cmx' => 'cmx',
            'image/x-epson-erf' => 'erf',
            'image/x-freehand' => 'fh',
            'image/x-fuji-raf' => 'raf',
            'image/x-icon' => 'ico',
            'image/x-kodak-dcr' => 'dcr',
            'image/x-kodak-k25' => 'k25',
            'image/x-kodak-kdc' => 'kdc',
            'image/x-minolta-mrw' => 'mrw',
            'image/x-nikon-nef' => 'nef',
            'image/x-olympus-orf' => 'orf',
            'image/x-panasonic-raw' => 'raw',
            'image/x-pcx' => 'pcx',
            'image/x-pentax-pef' => 'pef',
            'image/x-pict' => 'pct',
            'image/x-portable-anymap' => 'pnm',
            'image/x-portable-bitmap' => 'pbm',
            'image/x-portable-graymap' => 'pgm',
            'image/x-portable-pixmap' => 'ppm',
            'image/x-rgb' => 'rgb',
            'image/x-sigma-x3f' => 'x3f',
            'image/x-sony-arw' => 'arw',
            'image/x-sony-sr2' => 'sr2',
            'image/x-sony-srf' => 'srf',
            'image/x-xbitmap' => 'xbm',
            'image/x-xpixmap' => 'xpm',
            'image/x-xwindowdump' => 'xwd',
        ];
    }
}

/**
 * Get asset full url
 *
 * @param string $asset
 *
 * @return string
 */
if ( ! function_exists( 'pics_assets_url' ) ) {
	function pics_assets_url( string $asset ): string {
		return plugins_url( 'pics.io' ) . '/assets/' . $asset;
	}
}

/**
 * Get asset full path
 *
 * @param string $asset
 *
 * @return string
 */
if ( ! function_exists( 'pics_assets_path' ) ) {
	function pics_assets_path( string $asset ): string {
		return pics_root_path() . '/assets/' . $asset;
	}
}
