/* eslint-disable no-inner-declarations */
const ORIGIN = 'https://bundles.pics.io';
const SRC = 'https://bundles.pics.io/wordpress/production-latest/index.html';

/** @link https://codex.wordpress.org/Uploading_Files */
const SUPPORTED_EXTENSIONS = {
  images: ['jpg', 'jpeg', 'png', 'gif', 'ico', 'webp', 'bmp'], // webp & bpm - not in list but tested
  video: ['mp4', 'm4v', 'mov', 'wmv', 'avi', 'mpg', 'ogv', '3gp', '3g2'],
  audio: ['mp3', 'm4a', 'ogg', 'wav'],
};

function showDialog(title, text) {
  const body = `
<div class="picsio-modal-content">
  <div class="picsio-modal-close"></div>
  <div class="picsio-modal-title">${title}</div>
  <div>${text}</div>
</div>`;
  const $dialog = document.createElement('div');

  $dialog.classList.add('picsio-modal');
  $dialog.innerHTML = body;

  document.body.appendChild($dialog);

  /** Close */
  const $closeBtn = $dialog.querySelector('.picsio-modal-close');
  if ($closeBtn) {
    $closeBtn.addEventListener('click', () => {
      document.body.removeChild($dialog);
    });
  }
}

async function waitForSelector(selector, parent = document, maxCount = 5, interval = 500) {
  let count = 0;
  let $el = null;

  do {
    // eslint-disable-next-line no-await-in-loop
    $el = await new Promise((resolve) => {
      setTimeout(() => {
        resolve(parent.querySelector(selector));
      }, interval);
    });
    count++; // eslint-disable-line
  } while (count < maxCount && !$el);

  return $el;
}

if (wp.media) {
  let isMultiple = false;
  let $iframe = null;

  const insertAssets = async (downloadLinks) => {
    const $modal = ($iframe && $iframe.closest('.media-modal')) || document.querySelector('.media-modal');
    const $spinner = document.createElement('div');
    $spinner.classList.add('picsio-spinner');
    $spinner.innerHTML = '<span>Loading...</span>';

    const destroy = function () {
      $modal.removeChild($spinner);
    };

    $modal.appendChild($spinner);

    const res = await fetch(`${window.wpApiSettings.root}picsio/v1/gallery/upload_assets`, {
      method: 'POST',
      headers: new Headers({
        'Content-Type': 'application/json',
        'X-WP-Nonce': window.wpApiSettings.nonce,
      }),
      body: JSON.stringify({ downloadLinks }),
    });
    const { files } = await res.json();

    if (!files) {
      showDialog('Error!', 'Something went wrong. Can not download selected assets, try again later.');
      return destroy();
    }

    // eslint-disable-next-line camelcase
    const paths = files.map(({ file, original_image }) => original_image || file);
    const names = paths.map((path) => path.split('/').pop());

    const $tab = await waitForSelector('#menu-item-browse', $modal);

    if (!$tab) {
      console.warn('Tab not found');
      return destroy();
    }

    $tab.click();
    const $select = await waitForSelector('#media-attachment-date-filters', $modal);

    if (!$select) {
      console.warn('Select date not found');
      return destroy();
    }
    $select.dispatchEvent(new Event('change'));

    const $firstLi = await waitForSelector(`li[aria-label="${names[0]}"]`, $modal);
    if (!$firstLi) {
      console.warn('List child with image not found');
      return destroy();
    }

    names
      .map((name) => document.querySelector(`li[aria-label="${name}"]`))
      .forEach((li) => {
        if (li) li.dispatchEvent(new Event('click'));
      });

    const $selectButton = await waitForSelector('.media-toolbar button.media-button-select', $modal);

    if (!$selectButton) {
      console.warn('Apply button not found');
      return destroy();
    }
    $selectButton.dispatchEvent(new Event('click'));

    destroy();
  };

  async function onMessage(event) {
    if (event.origin !== ORIGIN) return;

    if (event.data && event.data.picsio && event.data.picsio.urlsForUpload) {
      insertAssets(event.data.picsio.urlsForUpload);
    }
  }

  const Picsio = wp.media.View.extend({
    tagName: 'iframe',
    className: 'picsio-widget',
    active: false,
    toolbar: null,
    frame: null,
    ready() {
      window.removeEventListener('message', onMessage);

      isMultiple = this.controller.options.multiple;
      $iframe = this.$el[0];

      $iframe.src = SRC;

      /** Subscribe */
      window.addEventListener('message', onMessage);

      $iframe.addEventListener('load', () => {
        /** Send */
        $iframe.contentWindow.postMessage({
          picsio: {
            isMultiple,
            extensions: SUPPORTED_EXTENSIONS.images,
          },
        }, '*');
      });
      return this;
    },
  });

  function extendType(type) {
    return {
      bindHandlers() {
        type.prototype.bindHandlers.apply(this, arguments);
        this.on('content:render:picsio', this.picsioContent, this);
      },

      browseRouter(routerView) {
        type.prototype.browseRouter.apply(this, arguments);
        routerView.set({
          picsio: {
            text: 'Pics.io',
            priority: 60,
          },
        });
      },

      picsioContent() {
        this.$el.addClass('hide-toolbar');
        const state = this.state();
        const view = new Picsio({ controller: this, model: state }).render();
        this.content.set(view);
      },
    };
  }

  const MediaFrame = wp.media.view.MediaFrame.Select;
  const MediaFramePost = wp.media.view.MediaFrame.Post;
  wp.media.view.MediaFrame.Select = MediaFrame.extend(extendType(MediaFrame));
  wp.media.view.MediaFrame.Post = MediaFramePost.extend(extendType(MediaFramePost));
}
